"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.expandShorthand = void 0;

var inline_style_expand_shorthand_1 = /*#__PURE__*/require("inline-style-expand-shorthand");
/**
 * A function that expands longhand properties ("margin", "padding") to their shorthand versions ("margin-left", etc.).
 * Follows CSS-like order in expansion i.e. last defined property wins.
 */


function expandShorthand(style, result) {
  if (result === void 0) {
    result = {};
  } // eslint-disable-next-line guard-for-in


  for (var property in style) {
    var value = style[property];

    if (typeof value === 'string' || typeof value === 'number') {
      var expansion = inline_style_expand_shorthand_1.expandProperty(property, value);

      if (expansion) {
        Object.assign(result, expansion);
      } else {
        result[property] = value;
      } // eslint-disable-next-line eqeqeq

    } else if (value == null) {// should skip
    } else if (Array.isArray(value)) {
      result[property] = value;
    } else if (typeof value === 'object') {
      result[property] = expandShorthand(value);
    }
  }

  return result;
}

exports.expandShorthand = expandShorthand;
//# sourceMappingURL=expandShorthand.js.map