import { reduceToClassNameForSlots } from './runtime/reduceToClassNameForSlots';
/**
 * A version of makeStyles() that accepts build output as an input and skips all runtime transforms.
 *
 * @internal
 */

export function __styles(classesMapBySlot, cssRules) {
  var insertionCache = {};
  var ltrClassNamesForSlots = null;
  var rtlClassNamesForSlots = null;

  function computeClasses(options) {
    var dir = options.dir,
        renderer = options.renderer;
    var isLTR = dir === 'ltr'; // As RTL classes are different they should have a different cache key for insertion

    var rendererId = isLTR ? renderer.id : renderer.id + 'r';

    if (isLTR) {
      if (ltrClassNamesForSlots === null) {
        ltrClassNamesForSlots = reduceToClassNameForSlots(classesMapBySlot, dir);
      }
    } else {
      if (rtlClassNamesForSlots === null) {
        rtlClassNamesForSlots = reduceToClassNameForSlots(classesMapBySlot, dir);
      }
    }

    if (insertionCache[rendererId] === undefined) {
      renderer.insertCSSRules(cssRules);
      insertionCache[rendererId] = true;
    }

    return isLTR ? ltrClassNamesForSlots : rtlClassNamesForSlots;
  }

  return computeClasses;
}
//# sourceMappingURL=__styles.js.map