import { Properties as CSSProperties } from 'csstype';
export interface MakeStyles extends Omit<CSSProperties, 'animationName'> {
    [key: string]: any;
    animationName?: object | string;
}
export declare type MakeStylesStyleFunctionRule<Tokens> = (tokens: Tokens) => MakeStyles;
export declare type MakeStylesStyleRule<Tokens> = MakeStyles | MakeStylesStyleFunctionRule<Tokens>;
export interface MakeStylesOptions {
    dir: 'ltr' | 'rtl';
    renderer: MakeStylesRenderer;
}
export declare type MakeStaticStyles = ({
    [key: string]: CSSProperties & Record<string, any>;
} & {
    '@font-face'?: {
        fontFamily: string;
        src: string;
        fontFeatureSettings?: string;
        fontStretch?: string;
        fontStyle?: string;
        fontVariant?: string;
        fontVariationSettings?: string;
        fontWeight?: number | string;
        unicodeRange?: string;
    };
}) | string;
export interface MakeStaticStylesOptions {
    renderer: MakeStylesRenderer;
}
export interface MakeStylesRenderer {
    id: string;
    /**
     * @private
     */
    insertionCache: Record<string, StyleBucketName>;
    /**
     * @private
     */
    styleElements: Partial<Record<StyleBucketName, HTMLStyleElement>>;
    /**
     * @private
     */
    insertCSSRules(cssRules: CSSRulesByBucket): void;
}
/**
 * Buckets under which we will group our stylesheets.
 */
export declare type StyleBucketName = 'd' | 'l' | 'v' | 'w' | 'f' | 'i' | 'h' | 'a' | 'k' | 't';
export declare type SequenceHash = string;
export declare type PropertyHash = string;
export declare type CSSClasses = /* ltrClassName */ string | [/* ltrClassName */ string, /* rtlClassName */ string];
export declare type CSSClassesMap = Record<PropertyHash, CSSClasses>;
export declare type CSSClassesMapBySlot<Slots extends string | number> = Record<Slots, CSSClassesMap>;
export declare type CSSRulesByBucket = Partial<Record<StyleBucketName, string[]>>;
export declare type StylesBySlots<Slots extends string | number, Tokens> = Record<Slots, MakeStylesStyleRule<Tokens>>;
export declare type LookupItem = [/* definitions */ CSSClassesMap, /* dir */ /* dir */ 'rtl' | 'ltr'];
